@@ -21,7 +21,6 @@ def serve(
     ),
     max_num_seq: int = typer.Option(2, help="The maximum number of sequences."),
     max_model_len: int = typer.Option(4096, help="The maximum model length."),
-    local: bool = typer.Option(False, help="Whether to load the model locally."),
 ):
     from mw_python_sdk.llm.inference import serve
 
@@ -36,7 +35,6 @@ def serve(
         quantization=quantization,
         load_format=load_format,
         enforce_eager=enforce_eager,
-        local=local
     )
 
 
