@@ -1,5 +1,6 @@
 import uvicorn
 import json
+import os
 import tempfile
 import subprocess
 from typing import Optional
@@ -23,12 +24,11 @@ def serve(
     quantization: Optional[str] = None,
     load_format: Optional[str] = None,
     enforce_eager: bool = False,
-    local: bool = False,
 ):
     if model_id == "_echo_":
         uvicorn.run("mw_python_sdk.llm.echo_server:app", host=host, port=port)
     else:
-        if local:
+        if os.path.exists(model_id):
             model_dir = model_id
         else:
             model_dir = download_dir(model_id)
@@ -50,6 +50,7 @@ def serve(
                     f"python -m vllm.entrypoints.openai.api_server --tensor-parallel-size {tensor_parallel_size} "
                     f"--max-num-seq={max_num_seq} "
                     f"--max-model-len={max_model_len} --served-model-name={model_name} "
+                    f"--trust-remote-code "
                     f"--dtype={dtype} --model '{model_dir}' --host {host} --port {port} {extra_arguments}"
                 ),
             ]
